@@ -1,13 +1,14 @@
 import types
 from abc import abstractmethod
 from itertools import product
-from typing import Any, Callable, List, Optional, Protocol, Tuple
+from typing import Any, Callable, Optional, Protocol
 
 import torch
 from torch import Tensor
 from torch.nn import BatchNorm1d, Conv1d, Module, Parameter
 from torch.nn.utils.parametrize import register_parametrization
 
+from elasticai.creator.mlframework import Module, Tensor
 from elasticai.creator.precomputation.input_domains import (
     create_codomain_for_1d_conv,
     create_codomain_for_depthwise_1d_conv,
@@ -17,27 +18,7 @@ from elasticai.creator.qat.functional import binarize as BinarizeFn
 from elasticai.creator.tags_utils import TaggedModule
 
 """Implementation of quantizers and quantized variants of pytorch layers"""
-
-
-class Quantize(Protocol):
-    """
-    Protocol to be adhered to by quantizations with properties to simplify translation to other levels of abstraction.
-    Codomain is used for precalculation of convolutions by obtaining the codomain of the quantization prior to the convolution.
-    Threshold is used on MVTUs.
-    """
-
-    def __call__(self, *args: Any, **kwargs: Any) -> Tensor:
-        ...
-
-    @property
-    @abstractmethod
-    def codomain(self) -> List[float]:
-        ...
-
-    @property
-    @abstractmethod
-    def thresholds(self) -> List[float]:
-        ...
+Quantize = Module
 
 
 class Binarize(torch.nn.Module):
@@ -51,14 +32,6 @@ class Binarize(torch.nn.Module):
     def forward(x):
         return BinarizeFn.apply(x)
 
-    @property
-    def codomain(self):
-        return [-1, 1]
-
-    @property
-    def thresholds(self):
-        return torch.Tensor([0.0])
-
     @staticmethod
     def right_inverse(x: Tensor) -> Tensor:
         return x
@@ -92,18 +65,10 @@ class Ternarize(torch.nn.Module):
             no_gradient = rounded - clipped
         return clipped + no_gradient
 
-    @property
-    def codomain(self):
-        return [-1, 0, 1]
-
     @staticmethod
     def right_inverse(x: Tensor) -> Tensor:
         return x
 
-    @property
-    def thresholds(self):
-        return torch.Tensor([0.5 / self.widening_factor, -0.5 / self.widening_factor])
-
 
 class ResidualQuantization(torch.nn.Module):
     """
@@ -128,18 +93,6 @@ class ResidualQuantization(torch.nn.Module):
             out.append(out[-1] - torch.abs(factor) * bin(out[-1]))
         return bin(torch.cat(out, dim=1))
 
-    @property
-    def codomain(self):
-        return list(product([-1, 1], repeat=self.num_bits))
-
-    @property
-    def thresholds(self):
-        threshold = [torch.Tensor([0.0])]
-        for factor in self.weight:
-            threshold.append(threshold[-1] + torch.abs(factor))
-
-        return torch.flatten(torch.stack(threshold, 0))
-
 
 class QuantizeTwoBit(torch.nn.Module):
     """
@@ -158,14 +111,6 @@ class QuantizeTwoBit(torch.nn.Module):
         second_half = input - self.factors * binarize(input)
         return binarize(torch.cat((first_half, second_half), dim=1))
 
-    @property
-    def codomain(self):
-        return [[x, y] for x in [-1, 1] for y in [-1, 1]]
-
-    @property
-    def thresholds(self):
-        return torch.cat((torch.Tensor([0.0]), self.factors), 0)
-
 
 def _init_quantizable_convolution(self, quantizer, bias, constraints):
     if isinstance(quantizer, Module):
@@ -195,11 +140,11 @@ class QConv1d(torch.nn.Conv1d):
         self,
         in_channels: int,
         out_channels: int,
-        kernel_size: Tuple[int],
+        kernel_size: tuple[int],
         quantizer: Module,
-        stride: Tuple[int] = (1,),
+        stride: tuple[int] = (1,),
         padding: int = 0,
-        dilation: Tuple[int] = (1,),
+        dilation: tuple[int] = (1,),
         groups: int = 1,
         bias: bool = True,
         padding_mode: str = "zeros",
@@ -331,8 +276,8 @@ class QLSTMCell(torch.nn.LSTMCell):
         return input_tensor
 
     def forward(
-        self, x: torch.Tensor, hx: Optional[Tuple[torch.Tensor, torch.Tensor]] = None
-    ) -> Tuple[torch.Tensor, torch.Tensor]:
+        self, x: torch.Tensor, hx: Optional[tuple[torch.Tensor, torch.Tensor]] = None
+    ) -> tuple[torch.Tensor, torch.Tensor]:
         # Implementation based on
         # https://github.com/pytorch/pytorch/blob/e9ef087d2d12051341db485c8ac64ea64649823d/benchmarks/fastrnns/cells.py#L25
         if hx is None:
@@ -410,8 +355,8 @@ class QLSTM(torch.nn.Module):
         self.batch_first = batch_first
 
     def forward(
-        self, input: torch.Tensor, state: Tuple[torch.Tensor, torch.Tensor] = None
-    ) -> Tuple[torch.Tensor, Optional[Tuple[torch.Tensor, torch.Tensor]]]:
+        self, input: torch.Tensor, state: tuple[torch.Tensor, torch.Tensor] = None
+    ) -> tuple[torch.Tensor, Optional[tuple[torch.Tensor, torch.Tensor]]]:
         if self.batch_first:
             input = torch.stack(torch.unbind(input), dim=1)
 
