@@ -1,28 +1,37 @@
 import unittest
+from functools import partial
 
+from elasticai.creator.vhdl.number_representations import float_values_to_fixed_point
 from elasticai.creator.vhdl.precomputed_scalar_function import (
     precomputed_scalar_function_process,
 )
 
 
 class PrecomputedScalarFunctionProcessTest(unittest.TestCase):
+    def setUp(self) -> None:
+        self.fp_list = partial(float_values_to_fixed_point, total_bits=16, frac_bits=8)
+
     def test_empty_x_list_y_list_one_element(self) -> None:
         self.assertEqual(
-            list(precomputed_scalar_function_process(x_list=[], y_list=[1])),
+            list(precomputed_scalar_function_process(x=[], y=self.fp_list([1]))()),
             ['y <= "0000000100000000";'],
         )
 
     def test_empty_x_list_y_list_too_many_elements(self) -> None:
         with self.assertRaises(ValueError):
-            list(precomputed_scalar_function_process(x_list=[], y_list=[1, 2]))
+            list(precomputed_scalar_function_process(x=[], y=self.fp_list([1, 2]))())
 
     def test_empty_y_list(self) -> None:
         with self.assertRaises(ValueError):
-            list(precomputed_scalar_function_process(x_list=[], y_list=[]))
+            list(precomputed_scalar_function_process(x=[], y=[])())
 
     def test_x_list_lengths_not_suitable_for_y_list_lengths(self) -> None:
         with self.assertRaises(ValueError):
-            list(precomputed_scalar_function_process(x_list=[1, 2], y_list=[1]))
+            list(
+                precomputed_scalar_function_process(
+                    x=self.fp_list([1, 2]), y=self.fp_list([1])
+                )()
+            )
 
     def test_x_list_with_only_one_element(self) -> None:
         expected_code = [
@@ -34,7 +43,11 @@ class PrecomputedScalarFunctionProcessTest(unittest.TestCase):
         ]
         self.assertEqual(
             expected_code,
-            list(precomputed_scalar_function_process(x_list=[1], y_list=[1, 2])),
+            list(
+                precomputed_scalar_function_process(
+                    x=self.fp_list([1]), y=self.fp_list([1, 2])
+                )()
+            ),
         )
 
     def test_unsorted_x_list(self) -> None:
@@ -53,7 +66,7 @@ class PrecomputedScalarFunctionProcessTest(unittest.TestCase):
             expected_code,
             list(
                 precomputed_scalar_function_process(
-                    x_list=[3, 1, 2], y_list=[1, 2, 3, 4]
-                )
+                    x=self.fp_list([3, 1, 2]), y=self.fp_list([1, 2, 3, 4])
+                )()
             ),
         )
