@@ -1,7 +1,8 @@
-import math
 from collections.abc import Sequence
+from dataclasses import dataclass
 
 from elasticai.creator.resource_utils import read_text
+from elasticai.creator.vhdl.components.utils import calculate_addr_width, pad_with_zeros
 from elasticai.creator.vhdl.language import Code, hex_representation
 from elasticai.creator.vhdl.number_representations import (
     FixedPoint,
@@ -9,30 +10,19 @@ from elasticai.creator.vhdl.number_representations import (
 )
 
 
-def pad_with_zeros(numbers: list[FixedPoint], target_length: int) -> list[FixedPoint]:
-    zero = FixedPoint(0, *infer_total_and_frac_bits(numbers))
-    return numbers + [zero] * (target_length - len(numbers))
-
-
+@dataclass
 class RomComponent:
-    def __init__(
-        self,
-        rom_name: str,
-        values: Sequence[FixedPoint],
-        resource_option: str,
-    ) -> None:
-        self.rom_name = rom_name
-        self.data_width, _ = infer_total_and_frac_bits(values)
-        self.addr_width = self._calculate_required_addr_width_to_access_items(values)
-        padded_values = pad_with_zeros(list(values), 2**self.addr_width)
+    rom_name: str
+    values: Sequence[FixedPoint]
+    resource_option: str
+
+    def __post_init__(self) -> None:
+        self.data_width, _ = infer_total_and_frac_bits(self.values)
+        self.addr_width = calculate_addr_width(len(self.values))
+        padded_values = pad_with_zeros(list(self.values), 2**self.addr_width)
         self.hex_values = list(
             map(lambda fp: hex_representation(fp.to_hex()), padded_values)
         )
-        self.resource_option = resource_option
-
-    @staticmethod
-    def _calculate_required_addr_width_to_access_items(items: Sequence) -> int:
-        return max(1, math.ceil(math.log2(len(items))))
 
     @property
     def file_name(self) -> str:
